import { select, 
        csv, 
        scaleLinear, 
        max, 
        scaleBand,
        axisLeft,
       	axisBottom,
        format 
       } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 100, right: 10, bottom: 20, left: 50 };
  console.log(margin);
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0 , innerWidth]);
  
  //console.log(xScale.domain());
  //console.log(xScale.range());
  
  
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.2);
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.top}, ${margin.left})`);

	const xAxis = axisBottom(xScale)
  	.tickFormat(format('.3s'));
  
  g.append('g')
  	.call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
    	.remove();
  
  g.append('g').call(xAxis)
  	.attr('transform', `translate(${0}, ${innerHeight})`)
    .select('.domain')
    	.remove();
  		
  
  //enter() permit here to append rectangles elements to all the entries of the array
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth());
  
  g.append('text')
  	.text('Country Populations')
  	.attr('y', -10)
  	.attr('x', );
 
};

//parse the content of an .csv file into an array
csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  //console.log(data);
  render(data);
  
});